package com.ibm.hpt.gateway;

/**
 * Licensed Material - Property of IBM 
 * (C) Copyright IBM Corp. 2001 - All Rights Reserved 
 * 
 * DISCLAIMER: 
 * The following [enclosed] code is sample code created by IBM 
 * Corporation.  This sample code is not part of any standard IBM product 
 * and is provided to you solely for the purpose of assisting you in the 
 * development of your applications.  The code is provided 'AS IS', 
 * without warranty or condition of any kind.  IBM shall not be liable for any damages 
 * arising out of your use of the sample code, even if IBM has been 
 * advised of the possibility of such damages.
 **/ 
/**
 * Class Description:
 * This is an implementation class of LogonChecker Interface, and
 * provided as a sample program for RACF security check on OS/390 System.
 * Creation date: (5/21/01 1:17:10 PM)
 **/

import com.ibm.vgj.cso.*;
import java.util.*;
 
import com.ibm.os390.security.*;
import com.ibm.os390.security.PlatformSecurityServer;
 
import java.lang.Integer;

 
public class RACFValidateLogin implements LogonChecker
{
	/**
	 * Copyright information.
	 */
	public static final String COPYRIGHT = "(C) Copyright IBM Corporation 2001";
	
	private static final String 		_expiredPassword 			= "168";
	private static final String[] 	_invalidPassword 			= {"111", "169"};
	private static final String[] 	_invalidUserId 			= {"143", "163"};
	
	private static final String		_nullEntry				= NULL_ENTRY;
	private static final String     	_unknownSecurityError 		= UNKNOWN_SECURITY_ERROR;
	private static final String		_invalidChangedPassword		= CHANGE_PASSWORD_ERROR;

	private Hashtable _RACFErrorCodeMap						= new Hashtable();	
/**
 * Created for Logon Security Check.
 * RACFValidateLogin constructor. 
 * Creation date: (5/21/01 1:26:11 PM)
 */
public RACFValidateLogin() 
{
	setRACFErrorCodeMap();	
}
/**
 * Created for Logon Security Check.
 * Expired password will be changed by changePassword method in RACF API.
 *
 * Creation date: (5/21/01 1:32:01 PM)
 * @param userid java.lang.String
 * @param password java.lang.String
 * @param newpassword java.lang.String
 * @exception com.ibm.vgj.cso.CSOException The exception description.
 */
public void changePassword(String userid, String password, String newpassword) throws com.ibm.vgj.cso.CSOException 
{
	PlatformReturned pr = PlatformUser.changePassword(userid,password, newpassword);

	if (pr != null) 
		throw new CSOException(CSOMessage.CHANGE_PASSWORD_ERROR, new Object[] {"Racf errno = "+ pr.errno + ", " + "Racf errno2 = " + pr.errno2});
}
/**
 * Insert the method's description here.
 * Creation date: (6/1/01 1:22:02 PM)
 * @return java.lang.String
 */
public String getChangedPasswordError() 
{
	return _invalidChangedPassword;
}
/**
 * Insert the method's description here.
 * Creation date: (5/21/01 1:32:53 PM)
 * @return java.lang.String
 */
public String getExpiredPassword() 
{
	return _expiredPassword;
}
/**
 * Insert the method's description here.
 * Creation date: (5/21/01 1:33:29 PM)
 * @return java.lang.String[]
 */
public String[] getInvalidPassword() 
{
	return _invalidPassword;
}
/**
 * Insert the method's description here.
 * Creation date: (5/21/01 1:34:26 PM)
 * @return java.lang.String[]
 */
public String[] getInvalidUserId() 
{
	return _invalidUserId;
}
/**
 * Insert the method's description here.
 * Creation date: (5/21/01 1:35:03 PM)
 * @return java.lang.String
 */
public String getNullEntry() 
{
	return _nullEntry;
}
/**
 * Insert the method's description here.
 * Creation date: (5/21/01 1:19:08 PM)
 * @return java.lang.String
 */
public String getUnknownSecurityError() 
{
	return _unknownSecurityError;
}
/**
 * Created for Logon Security Check.
 * This method checks if the VAGenGateway is on OS/390 System, and RACFSecurity is set.
 * Creation date: (5/21/01 1:21:18 PM)
 * @return boolean
 */
public boolean isSecuritySet() 
{
	boolean securitySet = false;
	//Check to see if the operating system is os/390
	if (System.getProperty("os.name").equals("OS/390"))  
	{
		//Check to see if a resource type RACF class is active
		if (PlatformSecurityServer.isActive())
			securitySet = true;
	}
	return securitySet;
}
/**
 * Created for Logon Security Check.
 * This method performs user authentication to the RACF Security using RACF API.
 * In case of a security error, it retrieves CSOErrorMessage equivalent to RACF
 * error message(s),and throws appropriate CSOException to the Gateway Servlet.
 * 
 * Creation date: (5/21/01 1:27:00 PM)
 * @return boolean
 * @param userid java.lang.String
 * @param password java.lang.String
 * @exception com.ibm.vgj.cso.CSOException The exception description.
 */
public boolean isUserValid(String userid, String password) throws com.ibm.vgj.cso.CSOException 
{
	String errorNo = null;

	if(isSecuritySet())
	{	// First check to see if userid, and password values are set.
		String nullParameter = "";
		if(userid == null || userid.trim().length() == 0)
			nullParameter +=" *userid";
		if(password == null || password.trim().length() == 0)
			nullParameter +=" *password";
			
		//If userid, and password are set, then examine the RACF Error Messages.
		if(nullParameter.length() == 0 || nullParameter == null)
		{
			PlatformReturned pr = PlatformUser.authenticate(userid,password); 
			if (pr != null) 
			{
			  	errorNo = (String)_RACFErrorCodeMap.get( java.lang.Integer.toString(pr.errno));
			  	if ( errorNo != null )
			  	{
	 		  		if ( errorNo == INVALID_GTWPASSWORD) 
			 			throw new CSOException(CSOMessage.INVALID_GTWPASSWORD, new Object[] {"Racf errno = "+ pr.errno + ", " + "Racf errno2 = " + pr.errno2});
			  		if ( errorNo == INVALID_GTWUSERID)
			 			throw new CSOException(CSOMessage.INVALID_GTWUSERID, new Object[]   {"Racf errno = "+ pr.errno + ", " + "Racf errno2 = " + pr.errno2});
			  		if ( errorNo == EXPIRED_GTWPASSWORD)
			 			throw new CSOException(CSOMessage.EXPIRED_GTWPASSWORD, new Object[] {"Racf errno = "+ pr.errno + ", " + "Racf errno2 = " + pr.errno2});
		 			else
			 			throw new CSOException(CSOMessage.UNKNOWN_SECURITY_ERROR, new Object[] {"Racf errno = "+ pr.errno + ", " + "Racf errno2 = " + pr.errno2});			 			
			 	}
		 		return false;
			}
		}
		else
			throw new CSOException(CSOMessage.NULL_ENTRY, new Object[] {nullParameter});
				
		//Security is set, and user authenticated without any problems.
		return true; 	
	}
	
	//Security is not set.	
	return true;

}
/**
 * Created for Logon Security Check.
 * This method fills _RACFErrorCodeMap HashTable. In the HashTable, 
 * RACF Security error numbers returned by RACF API are mapped to the 
 * error numbers defined in the LogonCheckerInterface.
 *
 * The RACF Error Numbers for _expiredPassword, _invalidPassword[], and _invalidUserId[]
 * variables were initialized globally in the RACFValidateLogin.
 
 * Creation date: (5/21/01 1:30:59 PM)
 */
public void setRACFErrorCodeMap() 
{
	String[]	invalidPassword			= getInvalidPassword();
	String[]	invalidUserId			= getInvalidUserId();
	String 		expiredPassword			= getExpiredPassword();
	String		nullEntry				= getNullEntry();
	String      unknownSecurityError 	= getUnknownSecurityError();
	String      invalidChangedPassword  = getChangedPasswordError();
	
	
	_RACFErrorCodeMap.put(expiredPassword, LogonChecker.EXPIRED_GTWPASSWORD);	
	_RACFErrorCodeMap.put(nullEntry, LogonChecker.NULL_ENTRY);	
	_RACFErrorCodeMap.put(unknownSecurityError, LogonChecker.UNKNOWN_SECURITY_ERROR);		
	_RACFErrorCodeMap.put(invalidChangedPassword, LogonChecker.CHANGE_PASSWORD_ERROR);
		
	for (int i=0; i < invalidPassword.length; i++)
			_RACFErrorCodeMap.put( invalidPassword[i], LogonChecker.INVALID_GTWPASSWORD );
	for ( int i=0; i < invalidUserId.length; i++ )
			_RACFErrorCodeMap.put( invalidUserId[i], LogonChecker.INVALID_GTWUSERID );
}
}
